@@ -128,21 +128,27 @@ impl Date {
         true
     }
 
-    /// Gets the value of `Date`.
+    /// Gets the days from Unix Epoch of this `Date`.
     #[inline(always)]
-    pub(crate) const fn value(self) -> i32 {
+    pub const fn days(self) -> i32 {
         self.0
     }
 
+    /// Creates a `Date` from the given days from Unix Epoch without checking validity.
+    ///
+    /// # Safety
+    /// This function is unsafe because the day value is not checked for validity!
+    /// Before using it, check that the value is correct.
     #[inline(always)]
-    pub(crate) const unsafe fn from_value_unchecked(value: i32) -> Self {
-        Date(value)
+    pub const unsafe fn from_days_unchecked(days: i32) -> Self {
+        Date(days)
     }
 
+    /// Creates a `Date` from the given days from Unix Epoch.
     #[inline]
-    pub(crate) const fn try_from_value(value: i32) -> Result<Self> {
-        if is_valid_date(value) {
-            Ok(unsafe { Date::from_value_unchecked(value) })
+    pub const fn try_from_days(days: i32) -> Result<Self> {
+        if is_valid_date(days) {
+            Ok(unsafe { Date::from_days_unchecked(days) })
         } else {
             Err(Error::OutOfRange)
         }
@@ -192,9 +198,9 @@ impl Date {
     /// `Date` adds days.
     #[inline]
     pub const fn add_days(self, days: i32) -> Result<Date> {
-        let result = self.value().checked_add(days);
+        let result = self.days().checked_add(days);
         match result {
-            Some(d) => Date::try_from_value(d),
+            Some(d) => Date::try_from_days(d),
             None => Err(Error::OutOfRange),
         }
     }
@@ -203,7 +209,7 @@ impl Date {
     pub(crate) fn add_interval_ym_internal(self, interval: IntervalYM) -> Result<Date> {
         let (year, month, day) = self.extract();
 
-        let mut new_month = month as i32 + interval.value();
+        let mut new_month = month as i32 + interval.months();
         let mut new_year = year;
 
         if new_month > MONTHS_PER_YEAR as i32 {
@@ -244,15 +250,15 @@ impl Date {
     /// `Date` subtracts `Date`. Returns the difference in days between two `Date`
     #[inline]
     pub const fn sub_date(self, date: Date) -> i32 {
-        self.value() - date.value()
+        self.days() - date.days()
     }
 
     ///`Date` subtracts days.
     #[inline]
     pub const fn sub_days(self, days: i32) -> Result<Date> {
-        let result = self.value().checked_sub(days);
+        let result = self.days().checked_sub(days);
         match result {
-            Some(d) => Date::try_from_value(d),
+            Some(d) => Date::try_from_days(d),
             None => Err(Error::OutOfRange),
         }
     }
@@ -285,7 +291,7 @@ impl Date {
     #[inline]
     pub fn day_of_week(self) -> WeekDay {
         // Add offset
-        let mut date = self.value() + UNIX_EPOCH_DOW as i32 - 1;
+        let mut date = self.days() + UNIX_EPOCH_DOW as i32 - 1;
         date %= 7;
         if date < 0 {
             date += 7;
@@ -320,7 +326,7 @@ impl PartialEq<Timestamp> for Date {
 impl PartialOrd<Timestamp> for Date {
     #[inline]
     fn partial_cmp(&self, other: &Timestamp) -> Option<Ordering> {
-        Some(self.and_zero_time().value().cmp(&other.value()))
+        Some(self.and_zero_time().usecs().cmp(&other.usecs()))
     }
 }
 
@@ -384,7 +390,7 @@ mod tests {
     #[test]
     fn test_date() {
         let date = Date::try_from_ymd(1970, 1, 1).unwrap();
-        assert_eq!(date.value(), 0);
+        assert_eq!(date.days(), 0);
         assert_eq!(date.extract(), (1970, 1, 1));
 
         let date = Date::try_from_ymd(1, 1, 1).unwrap();
@@ -427,11 +433,11 @@ mod tests {
 
         // Default
         {
-            let date = generate_date(0001, 1, 1);
+            let date = generate_date(1, 1, 1);
             let date2 = Date::parse("5", "ss").unwrap();
             assert_eq!(date, date2);
 
-            let date = generate_date(0001, 1, 1);
+            let date = generate_date(1, 1, 1);
             let date2 = Date::parse("", "").unwrap();
             assert_eq!(date, date2)
         }
@@ -559,17 +565,17 @@ mod tests {
         );
         assert_eq!(
             lower_date.add_days(366).unwrap(),
-            Date::try_from_ymd(0002, 1, 2).unwrap()
+            Date::try_from_ymd(2, 1, 2).unwrap()
         );
 
         let date = Date::try_from_ymd(5000, 6, 15).unwrap();
         assert_eq!(
             date.add_days(718).unwrap(),
-            Date::try_from_ymd(5002, 06, 03).unwrap()
+            Date::try_from_ymd(5002, 6, 3).unwrap()
         );
         assert_eq!(
             date.sub_days(718).unwrap(),
-            Date::try_from_ymd(4998, 06, 27).unwrap()
+            Date::try_from_ymd(4998, 6, 27).unwrap()
         );
         assert_eq!(date.sub_days(718).unwrap(), date.add_days(-718).unwrap());
         assert_eq!(date.sub_days(-718).unwrap(), date.add_days(718).unwrap());
@@ -649,9 +655,9 @@ mod tests {
         let interval = IntervalDT::try_from_dhms(12345, 12, 3, 5, 6).unwrap();
         assert!(date.add_interval_dt(interval).is_err());
 
-        let date = generate_date(0001, 1, 1);
+        let date = generate_date(1, 1, 1);
         let interval = IntervalDT::try_from_dhms(5, 4, 3, 2, 1).unwrap();
-        let expect = generate_ts(0001, 1, 6, 4, 3, 2, 1);
+        let expect = generate_ts(1, 1, 6, 4, 3, 2, 1);
         assert_eq!(date.clone().add_interval_dt(interval).unwrap(), expect);
 
         let interval = IntervalDT::try_from_dhms(0, 0, 0, 0, 1).unwrap();
@@ -822,7 +828,7 @@ mod tests {
 
         // Boundary test
         let upper_date = generate_date(9999, 12, 31);
-        let lower_date = generate_date(0001, 1, 1);
+        let lower_date = generate_date(1, 1, 1);
         let interval = IntervalYM::try_from_ym(0, 1).unwrap();
 
         assert!(upper_date.add_interval_ym(interval).is_err());
@@ -843,11 +849,11 @@ mod tests {
                 .unwrap()
                 .sub_time(Time::try_from_hms(12, 34, 56, 999999).unwrap())
                 .unwrap(),
-            generate_ts(9999, 12, 30, 11, 25, 03, 000001)
+            generate_ts(9999, 12, 30, 11, 25, 3, 1)
         );
 
         // Out of range
-        assert!(Date::try_from_ymd(0001, 1, 1)
+        assert!(Date::try_from_ymd(1, 1, 1)
             .unwrap()
             .sub_time(Time::try_from_hms(12, 34, 56, 999999).unwrap())
             .is_err());
@@ -856,9 +862,9 @@ mod tests {
     #[test]
     fn test_date_sub_timestamp() {
         let upper_date = generate_date(9999, 12, 31);
-        let lower_date = generate_date(0001, 1, 1);
+        let lower_date = generate_date(1, 1, 1);
         let upper_ts = generate_ts(9999, 12, 31, 23, 59, 59, 999999);
-        let lower_ts = generate_ts(0001, 1, 1, 0, 0, 0, 0);
+        let lower_ts = generate_ts(1, 1, 1, 0, 0, 0, 0);
         let ts = generate_ts(5000, 6, 15, 12, 30, 30, 500000);
 
         assert_eq!(
@@ -880,7 +886,7 @@ mod tests {
     #[test]
     fn test_date_sub_date() {
         let upper_date = generate_date(9999, 12, 31);
-        let lower_date = generate_date(0001, 1, 1);
+        let lower_date = generate_date(1, 1, 1);
         let date = generate_date(5000, 6, 15);
 
         assert_eq!(upper_date.sub_date(lower_date), 3652058);
@@ -913,7 +919,7 @@ mod tests {
     #[test]
     fn test_date_extract() {
         test_extract(1960, 12, 31);
-        test_extract(0001, 1, 1);
+        test_extract(1, 1, 1);
         test_extract(1969, 12, 31);
         test_extract(1969, 12, 30);
         test_extract(1970, 1, 1);
