@@ -25,8 +25,8 @@ impl Timestamp {
     /// Creates a new `Timestamp` from a date and a time.
     #[inline]
     pub const fn new(date: Date, time: Time) -> Self {
-        let value = date.value() as i64 * USECONDS_PER_DAY + time.value();
-        Timestamp(value)
+        let usecs = date.days() as i64 * USECONDS_PER_DAY + time.usecs();
+        Timestamp(usecs)
     }
 
     /// Extracts `(Date, Time)` from the timestamp.
@@ -45,13 +45,12 @@ impl Timestamp {
 
         unsafe {
             (
-                Date::from_value_unchecked(date as i32),
-                Time::from_value_unchecked(time),
+                Date::from_days_unchecked(date as i32),
+                Time::from_usecs_unchecked(time),
             )
         }
     }
 
-    #[allow(dead_code)]
     #[inline]
     pub(crate) fn date(self) -> Date {
         let date = if self.0.is_negative() && self.0 % USECONDS_PER_DAY != 0 {
@@ -59,29 +58,33 @@ impl Timestamp {
         } else {
             self.0 / USECONDS_PER_DAY
         };
-        unsafe { Date::from_value_unchecked(date as i32) }
+        unsafe { Date::from_days_unchecked(date as i32) }
     }
 
-    #[allow(dead_code)]
     #[inline]
     pub(crate) fn time(self) -> Time {
         let temp_time = self.0 % USECONDS_PER_DAY;
         if temp_time.is_negative() {
-            unsafe { Time::from_value_unchecked(temp_time as i64 + USECONDS_PER_DAY) }
+            unsafe { Time::from_usecs_unchecked(temp_time as i64 + USECONDS_PER_DAY) }
         } else {
-            unsafe { Time::from_value_unchecked(temp_time as i64) }
+            unsafe { Time::from_usecs_unchecked(temp_time as i64) }
         }
     }
 
-    /// Gets the value of `Timestamp`.
+    /// Gets the microseconds from Unix Epoch of `Timestamp`.
     #[inline(always)]
-    pub(crate) const fn value(self) -> i64 {
+    pub const fn usecs(self) -> i64 {
         self.0
     }
 
+    /// Creates a `Timestamp` from the given microseconds from Unix Epoch without checking validity.
+    ///
+    /// # Safety
+    /// This function is unsafe because the microsecond value is not checked for validity!
+    /// Before using it, check that the value is correct.
     #[inline(always)]
-    pub(crate) const unsafe fn from_value_unchecked(value: i64) -> Self {
-        Timestamp(value)
+    pub const unsafe fn from_usecs_unchecked(usecs: i64) -> Self {
+        Timestamp(usecs)
     }
 
     /// Formats `Timestamp` by given format string.
@@ -98,10 +101,11 @@ impl Timestamp {
         fmt.parse(input)
     }
 
+    /// Creates a `Timestamp` from the given microseconds from Unix Epoch
     #[inline]
-    pub(crate) const fn try_from_value(value: i64) -> Result<Self> {
-        if is_valid_timestamp(value) {
-            Ok(unsafe { Timestamp::from_value_unchecked(value) })
+    pub const fn try_from_usecs(usecs: i64) -> Result<Self> {
+        if is_valid_timestamp(usecs) {
+            Ok(unsafe { Timestamp::from_usecs_unchecked(usecs) })
         } else {
             Err(Error::OutOfRange)
         }
@@ -110,9 +114,9 @@ impl Timestamp {
     /// `Timestamp` adds `IntervalDT`
     #[inline]
     pub const fn add_interval_dt(self, interval: IntervalDT) -> Result<Timestamp> {
-        let result = self.value().checked_add(interval.value());
+        let result = self.usecs().checked_add(interval.usecs());
         match result {
-            Some(ts) => Timestamp::try_from_value(ts),
+            Some(ts) => Timestamp::try_from_usecs(ts),
             None => Err(Error::OutOfRange),
         }
     }
@@ -131,7 +135,7 @@ impl Timestamp {
     /// `Timestamp` add `Time`
     #[inline]
     pub const fn add_time(self, time: Time) -> Result<Timestamp> {
-        Timestamp::try_from_value(self.value() + time.value())
+        Timestamp::try_from_usecs(self.usecs() + time.usecs())
     }
 
     /// `Timestamp` add days
@@ -141,9 +145,9 @@ impl Timestamp {
         if !microseconds.is_finite() {
             return Err(Error::OutOfRange);
         }
-        let result = self.value().checked_add(microseconds as i64);
+        let result = self.usecs().checked_add(microseconds as i64);
         match result {
-            Some(d) => Timestamp::try_from_value(d),
+            Some(d) => Timestamp::try_from_usecs(d),
             None => Err(Error::OutOfRange),
         }
     }
@@ -158,14 +162,14 @@ impl Timestamp {
     /// `Timestamp` subtracts `Time`
     #[inline]
     pub const fn sub_time(self, time: Time) -> Result<Timestamp> {
-        Timestamp::try_from_value(self.value() - time.value())
+        Timestamp::try_from_usecs(self.usecs() - time.usecs())
     }
 
     /// `Timestamp` subtracts `Timestamp`
     #[inline]
     pub const fn sub_timestamp(self, timestamp: Timestamp) -> IntervalDT {
-        let microseconds = self.value() - timestamp.value();
-        unsafe { IntervalDT::from_value_unchecked(microseconds) }
+        let microseconds = self.usecs() - timestamp.usecs();
+        unsafe { IntervalDT::from_usecs_unchecked(microseconds) }
     }
 
     /// `Timestamp` subtracts `IntervalDT`
@@ -229,7 +233,7 @@ impl PartialEq<Date> for Timestamp {
 impl PartialOrd<Date> for Timestamp {
     #[inline]
     fn partial_cmp(&self, other: &Date) -> Option<Ordering> {
-        Some(self.value().cmp(&other.and_zero_time().value()))
+        Some(self.usecs().cmp(&other.and_zero_time().usecs()))
     }
 }
 
@@ -285,11 +289,10 @@ mod tests {
         sec: u32,
         usec: u32,
     ) -> Timestamp {
-        let timestamp = Timestamp::new(
+        Timestamp::new(
             Date::try_from_ymd(year, month, day).unwrap(),
             Time::try_from_hms(hour, min, sec, usec).unwrap(),
-        );
-        timestamp
+        )
     }
 
     fn generate_date(year: i32, month: u32, day: u32) -> Date {
@@ -306,28 +309,28 @@ mod tests {
             let date = Date::try_from_ymd(1970, 1, 1).unwrap();
             let time = Time::try_from_hms(0, 0, 0, 0).unwrap();
             let ts = Timestamp::new(date, time);
-            assert_eq!(ts.value(), 0);
+            assert_eq!(ts.usecs(), 0);
 
             let (date, time) = ts.extract();
             assert_eq!(date.extract(), (1970, 1, 1));
             assert_eq!(time.extract(), (0, 0, 0, 0));
 
-            let ts = generate_ts(0001, 1, 1, 0, 0, 0, 0);
+            let ts = generate_ts(1, 1, 1, 0, 0, 0, 0);
             let (date, time) = ts.extract();
             assert_eq!(date.extract(), (1, 1, 1));
             assert_eq!(time.extract(), (0, 0, 0, 0));
 
-            let ts = generate_ts(0001, 1, 1, 23, 59, 59, 999999);
+            let ts = generate_ts(1, 1, 1, 23, 59, 59, 999999);
             let (date, time) = ts.extract();
             assert_eq!(date.extract(), (1, 1, 1));
             assert_eq!(time.extract(), (23, 59, 59, 999999));
 
-            let ts = generate_ts(0001, 12, 31, 0, 0, 0, 0);
+            let ts = generate_ts(1, 12, 31, 0, 0, 0, 0);
             let (date, time) = ts.extract();
             assert_eq!(date.extract(), (1, 12, 31));
             assert_eq!(time.extract(), (0, 0, 0, 0));
 
-            let ts = generate_ts(0001, 12, 31, 23, 59, 59, 999999);
+            let ts = generate_ts(1, 12, 31, 23, 59, 59, 999999);
             let (date, time) = ts.extract();
             assert_eq!(date.extract(), (1, 12, 31));
             assert_eq!(time.extract(), (23, 59, 59, 999999));
@@ -451,11 +454,11 @@ mod tests {
 
             // Default
             {
-                let ts = generate_ts(0001, 1, 1, 0, 0, 5, 0);
+                let ts = generate_ts(1, 1, 1, 0, 0, 5, 0);
                 let ts2 = Timestamp::parse("5", "ss").unwrap();
                 assert_eq!(ts, ts2);
 
-                let ts = generate_ts(0001, 1, 1, 0, 0, 0, 0);
+                let ts = generate_ts(1, 1, 1, 0, 0, 0, 0);
                 let ts2 = Timestamp::parse("", "").unwrap();
                 assert_eq!(ts, ts2);
 
@@ -661,12 +664,12 @@ mod tests {
 
     #[test]
     fn test_timestamp_date_time() {
-        let ts = generate_ts(0001, 1, 1, 0, 0, 0, 0);
-        assert_eq!(ts.date(), generate_date(0001, 1, 1));
+        let ts = generate_ts(1, 1, 1, 0, 0, 0, 0);
+        assert_eq!(ts.date(), generate_date(1, 1, 1));
         assert_eq!(ts.time(), generate_time(0, 0, 0, 0));
 
-        let ts = generate_ts(0001, 1, 1, 23, 59, 59, 999999);
-        assert_eq!(ts.date(), generate_date(0001, 1, 1));
+        let ts = generate_ts(1, 1, 1, 23, 59, 59, 999999);
+        assert_eq!(ts.date(), generate_date(1, 1, 1));
         assert_eq!(ts.time(), generate_time(23, 59, 59, 999999));
 
         let ts = generate_ts(1969, 12, 30, 0, 0, 0, 0);
@@ -764,9 +767,9 @@ mod tests {
         let interval = IntervalDT::try_from_dhms(12345, 12, 3, 5, 6).unwrap();
         assert!(ts.add_interval_dt(interval).is_err());
 
-        let ts = generate_ts(0001, 1, 1, 0, 0, 0, 0);
+        let ts = generate_ts(1, 1, 1, 0, 0, 0, 0);
         let interval = IntervalDT::try_from_dhms(5, 4, 3, 2, 1).unwrap();
-        let expect = generate_ts(0001, 1, 6, 4, 3, 2, 1);
+        let expect = generate_ts(1, 1, 6, 4, 3, 2, 1);
         assert_eq!(ts.add_interval_dt(interval).unwrap(), expect);
 
         let interval = IntervalDT::try_from_dhms(0, 0, 0, 0, 1).unwrap();
@@ -906,7 +909,7 @@ mod tests {
 
         // Boundary test
         let upper_ts = generate_ts(9999, 12, 31, 23, 59, 59, 999999);
-        let lower_ts = generate_ts(0001, 1, 1, 0, 0, 0, 0);
+        let lower_ts = generate_ts(1, 1, 1, 0, 0, 0, 0);
         let interval = IntervalYM::try_from_ym(0, 1).unwrap();
 
         assert!(upper_ts.add_interval_ym(interval).is_err());
@@ -939,7 +942,7 @@ mod tests {
         let time = Time::try_from_hms(0, 0, 0, 1).unwrap();
         assert!(ts.add_time(time).is_err());
 
-        let ts = generate_ts(0001, 1, 1, 0, 0, 0, 0);
+        let ts = generate_ts(1, 1, 1, 0, 0, 0, 0);
         let time = Time::try_from_hms(5, 4, 3, 2).unwrap();
         assert!(ts.sub_time(time).is_err());
 
@@ -950,7 +953,7 @@ mod tests {
     #[test]
     fn test_timestamp_sub_timestamp() {
         let upper_ts = generate_ts(9999, 12, 31, 23, 59, 59, 999999);
-        let lower_ts = generate_ts(0001, 1, 1, 0, 0, 0, 0);
+        let lower_ts = generate_ts(1, 1, 1, 0, 0, 0, 0);
         let ts = generate_ts(5000, 6, 15, 12, 30, 30, 500000);
 
         assert_eq!(
@@ -972,8 +975,8 @@ mod tests {
     #[test]
     fn test_timestamp_sub_date() {
         let upper_ts = generate_ts(9999, 12, 31, 23, 59, 59, 999999);
-        let lower_ts = generate_ts(0001, 1, 1, 0, 0, 0, 0);
-        let lower_date = Date::try_from_ymd(0001, 1, 1).unwrap();
+        let lower_ts = generate_ts(1, 1, 1, 0, 0, 0, 0);
+        let lower_date = Date::try_from_ymd(1, 1, 1).unwrap();
         let upper_date = Date::try_from_ymd(9999, 12, 31).unwrap();
         let date = Date::try_from_ymd(5000, 6, 15).unwrap();
 
@@ -996,10 +999,10 @@ mod tests {
     #[test]
     fn test_timestamp_add_sub_days() {
         let upper_ts = generate_ts(9999, 12, 31, 23, 59, 59, 999999);
-        let lower_ts = generate_ts(0001, 1, 1, 0, 0, 0, 0);
+        let lower_ts = generate_ts(1, 1, 1, 0, 0, 0, 0);
 
         // Out of range
-        assert!(lower_ts.add_days(213435445784784.123).is_err());
+        assert!(lower_ts.add_days(213435445784784.13).is_err());
         assert!(lower_ts.add_days(f64::NAN).is_err());
         assert!(lower_ts.add_days(f64::INFINITY).is_err());
         assert!(lower_ts.add_days(f64::NEG_INFINITY).is_err());
@@ -1007,7 +1010,7 @@ mod tests {
         assert!(lower_ts.add_days(f64::MIN).is_err());
         assert!(upper_ts.add_days(0.0001).is_err());
 
-        assert!(lower_ts.sub_days(213435445784784.123).is_err());
+        assert!(lower_ts.sub_days(213435445784784.13).is_err());
         assert!(lower_ts.sub_days(f64::NAN).is_err());
         assert!(lower_ts.sub_days(f64::INFINITY).is_err());
         assert!(lower_ts.sub_days(f64::NEG_INFINITY).is_err());
@@ -1018,7 +1021,7 @@ mod tests {
         // Round
         assert_eq!(
             lower_ts.add_days(1.123456789).unwrap(),
-            generate_ts(0001, 1, 2, 2, 57, 46, 666570)
+            generate_ts(1, 1, 2, 2, 57, 46, 666570)
         );
         assert_eq!(
             upper_ts.sub_days(1.123456789).unwrap(),
@@ -1034,7 +1037,7 @@ mod tests {
         );
         assert_eq!(
             lower_ts.add_days(1.0).unwrap(),
-            generate_ts(0001, 1, 2, 0, 0, 0, 0)
+            generate_ts(1, 1, 2, 0, 0, 0, 0)
         );
 
         let ts = generate_ts(5000, 6, 15, 12, 30, 30, 555555);
@@ -1051,6 +1054,7 @@ mod tests {
         assert!(ts == date);
     }
 
+    #[allow(clippy::float_cmp)]
     fn test_extract(year: i32, month: u32, day: u32, hour: u32, min: u32, sec: u32, usec: u32) {
         let ts = generate_ts(year, month, day, hour, min, sec, usec);
         assert_eq!(year, ts.year().unwrap());
@@ -1067,8 +1071,8 @@ mod tests {
     #[test]
     fn test_timestamp_extract() {
         test_extract(1960, 12, 31, 23, 59, 59, 999999);
-        test_extract(0001, 1, 1, 0, 0, 0, 0);
-        test_extract(0001, 1, 1, 1, 1, 1, 1);
+        test_extract(1, 1, 1, 0, 0, 0, 0);
+        test_extract(1, 1, 1, 1, 1, 1, 1);
         test_extract(1969, 12, 31, 1, 2, 3, 4);
         test_extract(1969, 12, 30, 23, 59, 59, 999999);
         test_extract(1969, 12, 30, 0, 0, 0, 0);
